==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperAttributeReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Attribute reference details for the referred column.
 * @property entity Name of the table.
 * @property entityConnectionReference The connection reference for the connection.
 * @property name Name of the column.
 */
public data class MapperAttributeReferenceArgs(
    public val entity: Output<String>? = null,
    public val entityConnectionReference: Output<MapperConnectionReferenceArgs>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs.builder()
            .entity(entity?.applyValue({ args0 -> args0 }))
            .entityConnectionReference(
                entityConnectionReference?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MapperAttributeReferenceArgs].
 */
@PulumiTagMarker
public class MapperAttributeReferenceArgsBuilder internal constructor() {
    private var entity: Output<String>? = null

    private var entityConnectionReference: Output<MapperConnectionReferenceArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value Name of the table.
     */
    @JvmName("hsydyxsykheqxlqt")
    public suspend fun entity(`value`: Output<String>) {
        this.entity = value
    }

    /**
     * @param value The connection reference for the connection.
     */
    @JvmName("kvrsnqsaisssxicq")
    public suspend fun entityConnectionReference(`value`: Output<MapperConnectionReferenceArgs>) {
        this.entityConnectionReference = value
    }

    /**
     * @param value Name of the column.
     */
    @JvmName("jtxbcyladoygttio")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("cvmvwoitgwvkmvof")
    public suspend fun entity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entity = mapped
    }

    /**
     * @param value The connection reference for the connection.
     */
    @JvmName("gipxpafuadhpqteg")
    public suspend fun entityConnectionReference(`value`: MapperConnectionReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entityConnectionReference = mapped
    }

    /**
     * @param argument The connection reference for the connection.
     */
    @JvmName("jmohqyrmlntrpgvw")
    public suspend
    fun entityConnectionReference(argument: suspend MapperConnectionReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = MapperConnectionReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.entityConnectionReference = mapped
    }

    /**
     * @param value Name of the column.
     */
    @JvmName("gttysqdmyhebvqxi")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): MapperAttributeReferenceArgs = MapperAttributeReferenceArgs(
        entity = entity,
        entityConnectionReference = entityConnectionReference,
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/MapperAttributeReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Attribute reference details for the referred column.
 * @property entity Name of the table.
 * @property entityConnectionReference The connection reference for the connection.
 * @property name Name of the column.
 */
public data class MapperAttributeReferenceArgs(
    public val entity: Output<String>? = null,
    public val entityConnectionReference: Output<MapperConnectionReferenceArgs>? = null,
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs =
        com.pulumi.azurenative.datafactory.inputs.MapperAttributeReferenceArgs.builder()
            .entity(entity?.applyValue({ args0 -> args0 }))
            .entityConnectionReference(
                entityConnectionReference?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MapperAttributeReferenceArgs].
 */
@PulumiTagMarker
public class MapperAttributeReferenceArgsBuilder internal constructor() {
    private var entity: Output<String>? = null

    private var entityConnectionReference: Output<MapperConnectionReferenceArgs>? = null

    private var name: Output<String>? = null

    /**
     * @param value Name of the table.
     */
    @JvmName("cvanqvcbxtpxyljp")
    public suspend fun entity(`value`: Output<String>) {
        this.entity = value
    }

    /**
     * @param value The connection reference for the connection.
     */
    @JvmName("yqdnmhgsqfimuwlc")
    public suspend fun entityConnectionReference(`value`: Output<MapperConnectionReferenceArgs>) {
        this.entityConnectionReference = value
    }

    /**
     * @param value Name of the column.
     */
    @JvmName("nyqbieimsioaleus")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Name of the table.
     */
    @JvmName("qejwlxxeoobfslnp")
    public suspend fun entity(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entity = mapped
    }

    /**
     * @param value The connection reference for the connection.
     */
    @JvmName("uuabtjamxfsihcxv")
    public suspend fun entityConnectionReference(`value`: MapperConnectionReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.entityConnectionReference = mapped
    }

    /**
     * @param argument The connection reference for the connection.
     */
    @JvmName("kcemtiicxculxugc")
    public suspend
    fun entityConnectionReference(argument: suspend MapperConnectionReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = MapperConnectionReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.entityConnectionReference = mapped
    }

    /**
     * @param value Name of the column.
     */
    @JvmName("sklukqhwdfcdibsr")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): MapperAttributeReferenceArgs = MapperAttributeReferenceArgs(
        entity = entity,
        entityConnectionReference = entityConnectionReference,
        name = name,
    )
}
